Index: components/encryptor/os_crypt.h |
diff --git a/components/encryptor/encryptor.h b/components/encryptor/os_crypt.h |
similarity index 49% |
rename from components/encryptor/encryptor.h |
rename to components/encryptor/os_crypt.h |
index 48bb2e5969a664b58c623a8bd39c49b09f0cbd99..ae899aaa843fd495b24df30f855016dd59030aac 100644 |
--- a/components/encryptor/encryptor.h |
+++ b/components/encryptor/os_crypt.h |
@@ -2,28 +2,26 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef COMPONENTS_ENCRYPTOR_ENCRYPTOR_H_ |
-#define COMPONENTS_ENCRYPTOR_ENCRYPTOR_H_ |
+#ifndef COMPONENTS_ENCRYPTOR_OS_CRYPT_H_ |
+#define COMPONENTS_ENCRYPTOR_OS_CRYPT_H_ |
#include <string> |
#include "base/strings/string16.h" |
// The Encryptor class gives access to simple encryption and decryption of |
// strings. Note that on Mac, access to the system Keychain is required and |
// these calls can block the current thread to collect user input. |
-class Encryptor { |
+class OSCrypt { |
public: |
- // Encrypt a string16. The output (second argument) is |
- // really an array of bytes, but we're passing it back |
- // as a std::string |
+ // Encrypt a string16. The output (second argument) is really an array of |
+ // bytes, but we're passing it back as a std::string. |
static bool EncryptString16(const base::string16& plaintext, |
std::string* ciphertext); |
- // Decrypt an array of bytes obtained with EncryptString16 |
- // back into a string16. Note that the input (first argument) |
- // is a std::string, so you need to first get your (binary) |
- // data into a string. |
+ // Decrypt an array of bytes obtained with EncryptString16 back into a |
+ // string16. Note that the input (first argument) is a std::string, so you |
+ // need to first get your (binary) data into a string. |
static bool DecryptString16(const std::string& ciphertext, |
base::string16* plaintext); |
@@ -31,21 +29,20 @@ class Encryptor { |
static bool EncryptString(const std::string& plaintext, |
std::string* ciphertext); |
- // Decrypt an array of bytes obtained with EnctryptString |
- // back into a string. Note that the input (first argument) |
- // is a std::string, so you need to first get your (binary) |
- // data into a string. |
+ // Decrypt an array of bytes obtained with EnctryptString back into a string. |
+ // Note that the input (first argument) is a std::string, so you need to first |
+ // get your (binary) data into a string. |
static bool DecryptString(const std::string& ciphertext, |
std::string* plaintext); |
#if defined(OS_MACOSX) |
// For unit testing purposes we instruct the Encryptor to use a mock Keychain |
- // on the Mac. The default is to use the real Keychain. |
+ // on the Mac. The default is to use the real Keychain. |
static void UseMockKeychain(bool use_mock); |
#endif |
private: |
- DISALLOW_IMPLICIT_CONSTRUCTORS(Encryptor); |
+ DISALLOW_IMPLICIT_CONSTRUCTORS(OSCrypt); |
}; |
-#endif // COMPONENTS_ENCRYPTOR_ENCRYPTOR_H_ |
+#endif // COMPONENTS_ENCRYPTOR_OS_CRYPT_H_ |
@@ -2,28 +2,26 @@ |
#include <string> |
#include "base/strings/string16.h" |
-// The Encryptor class gives access to simple encryption and decryption of |
-// strings. Note that on Mac, access to the system Keychain is required and |
+// The OSCrypt class gives access to simple encryption and decryption of |
+// strings. Note that on Mac, access to the system Keychain is required and |
// these calls can block the current thread to collect user input. |